@@ -149,4 +149,66 @@ def get_records_by_key_condition(tablename,KeyConditionExpression,session = boto
         return False
 
     result = dynamodbTableRes.query(KeyConditionExpression=KeyConditionExpression)
-    return result
\ No newline at end of file
+    return result
+
+
+
+def delete_items_by_hashkey(dynamodbTableRes,hashkey):
+    """Given a dynamoDB table resource and a hashkey this function 
+    deletes all corresponding records
+
+    For tables with a hash and range key, this function can delete
+    several records at once.
+
+    Args:
+        dynamodbTableRes ([type]): Boto3 DDB table resource
+        hashkey (bool): Hashkey of records to delete
+
+    Returns:
+        [type]: [description]
+    """
+    
+    
+    
+    hashKeyName = None
+    rangeKeyName = None
+
+    # Get the HASH and RANGE key names
+    for ddbkey in table.key_schema:
+        KeyType = ddbkey['KeyType']
+        AttributeName  = ddbkey['AttributeName']
+
+        if KeyType == 'HASH':
+            hashKeyName = AttributeName
+
+        elif KeyType == 'RANGE':
+            rangeKeyName = AttributeName
+
+    # If table has a HASH key
+    if hashKeyName is not None:
+        KeyConditionExpression = Key(hashKeyName).eq(hashkey)
+        # Get all the items corresponding to the hashkey
+        result = get_records_by_key_condition(tablename = "",KeyConditionExpression= KeyConditionExpression,dynamodbTableRes = table)
+
+
+
+        # Delete items in batch - Include rangeKey if required
+        with table.batch_writer() as batch:
+            print("Deleting ", len(result['Items']), " items....")
+            for row in result['Items']:
+                if rangeKeyName is not None:
+                    batch.delete_item(
+                        Key={
+                            hashKeyName: hashkey,
+                            rangeKeyName: row[rangeKeyName]
+                        }
+                    )
+                else:
+                    batch.delete_item(
+                        Key={
+                            hashKeyName: hashkey
+                        }
+                    )
+                
+    else:
+        return "Invalid table..."
