@@ -31,9 +31,9 @@ Function can handle the following text encodings:
 
 
 
-def get_file_data_from_s3(bucket, key,s3 = boto3.client("s3")):
+def get_file_data_from_s3(bucket, key,session = boto3.Session() ):
 
-    #s3 = boto3.client("s3")
+    s3 = session.client("s3")
     raw_data = None
 
     #Read data from filename
@@ -76,8 +76,8 @@ Write data to s3
 
 ----------------------------------------------------------------------------------------
 """
-def write_to_s3(Bucket, Key, ioBuffer, Metadata = {'Meta0': 'Meta data not specifified'}, output_type ='json_gzip' ):
-    s3 = boto3.client("s3")
+def write_to_s3(Bucket, Key, ioBuffer, Metadata = {'Meta0': 'Meta data not specifified'}, output_type ='json_gzip',session = boto3.Session() ):
+    s3 = session.client("s3")
     try:
 
         if output_type == 'json_gzip':
@@ -128,7 +128,7 @@ Write JSON events to s3
 
 
 
-def write_json_events_array_to_s3(jsonEventsArray,Bucket, Key, Metadata = {'Meta0': 'Meta data not specified'}, output_type ='json_gzip', cls=None):
+def write_json_events_array_to_s3(jsonEventsArray,Bucket, Key, Metadata = {'Meta0': 'Meta data not specified'}, output_type ='json_gzip', cls=None, session = boto3.Session()):
 
     try:
 
@@ -158,7 +158,7 @@ def write_json_events_array_to_s3(jsonEventsArray,Bucket, Key, Metadata = {'Meta
         if output_type == 'json_gzip':
               io_buffer_gzip.close()
 
-        response = write_to_s3(Bucket = Bucket, Key = Key, ioBuffer = io_buffer, Metadata = Metadata, output_type =output_type)
+        response = write_to_s3(Bucket = Bucket, Key = Key, ioBuffer = io_buffer, Metadata = Metadata, output_type =output_type,session = session)
         return response
 
     except Exception as e:
@@ -180,7 +180,7 @@ get_matching_s3_objects
 
 """
 
-def get_matching_s3_objects(bucket, prefix="",  suffix="",suffix_list = [],s3 =boto3.client("s3")):
+def get_matching_s3_objects(bucket, prefix="",  suffix="",suffix_list = [],session = boto3.Session()):
     """
     Generate objects in an S3 bucket.
 
@@ -190,7 +190,7 @@ def get_matching_s3_objects(bucket, prefix="",  suffix="",suffix_list = [],s3 =b
     :param suffix: Only fetch objects whose keys end with
         this suffix (optional).
     """
-    #s3 = boto3.client("s3")
+    s3 = session.client("s3")
     paginator = s3.get_paginator("list_objects_v2")
 
     kwargs = {'Bucket': bucket}
@@ -230,9 +230,9 @@ def get_matching_s3_objects(bucket, prefix="",  suffix="",suffix_list = [],s3 =b
 get_matching_s3_keys
 ----------------------------------------------------------------------------------------
 """
-def get_matching_s3_keys(bucket, prefix="", suffix="", suffix_list = []):
+def get_matching_s3_keys(bucket, prefix="", suffix="", suffix_list = [], session = boto3.Session()):
 
-    for obj in get_matching_s3_objects(bucket, prefix, suffix,suffix_list):
+    for obj in get_matching_s3_objects(bucket, prefix, suffix,suffix_list,session):
         yield obj["Key"],obj["Size"]
 
 
@@ -241,11 +241,14 @@ def get_matching_s3_keys(bucket, prefix="", suffix="", suffix_list = []):
 get_matching_s3_keys_v2 - returns date_modified
 ----------------------------------------------------------------------------------------
 """
-def get_matching_s3_keys_v2(bucket, prefix="", suffix="", suffix_list = [],s3 =boto3.client("s3")):
+def get_matching_s3_keys_v2(bucket, prefix="", suffix="", suffix_list = [], session = boto3.Session()):
 
-    for obj in get_matching_s3_objects(bucket, prefix, suffix,suffix_list,s3):
+    for obj in get_matching_s3_objects(bucket, prefix, suffix,suffix_list,session):
         yield obj["Key"],obj["Size"], obj['LastModified']
 
 
 
+
+
+
         
\ No newline at end of file
