@@ -512,7 +512,7 @@ class EventUserMap:
         files = lookupDict["files"]
         
         for fileIndexOld, file in files.items():                
-            result, fileIndexNew = self.add_file(file["bucket"],file["key"])
+            result, fileIndexNew = self.add_file(file["bucket"],file["key"],userIdKey =file["userIdKey"])
 
             #IF file was added (e.g. same file is not present in the file)
             if result == True:
